@@ -8,6 +8,8 @@
 #
 
 package POE::Component::Server::Chargen;
+$POE::Component::Server::Chargen::VERSION = '1.16';
+#ABSTRACT: A POE component that implements an RFC 864 Chargen server.
 
 use strict;
 use warnings;
@@ -15,13 +17,10 @@ use Carp;
 use POE;
 use Socket;
 use base qw(POE::Component::Server::Echo);
-use vars qw($VERSION);
 
 use constant DATAGRAM_MAXLEN => 1024;
 use constant DEFAULT_PORT => 19;
 
-$VERSION = '1.14';
-
 sub spawn {
   my $package = shift;
   croak "$package requires an even number of parameters" if @_ & 1;
@@ -108,13 +107,22 @@ sub _generate_line {
   return $chargen_line;
 }
 
-1;
+qq[A Gen of chars];
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 POE::Component::Server::Chargen - A POE component that implements an RFC 864 Chargen server.
 
+=head1 VERSION
+
+version 1.16
+
 =head1 SYNOPSIS
 
  use POE::Component::Server::Chargen;
@@ -137,7 +145,7 @@ L<POE>. It is a class inherited from L<POE::Component::Server::Echo|POE::Compone
 
 =item C<spawn>
 
-Takes a number of optional values: 
+Takes a number of optional values:
 
   "Alias", the kernel alias that this component is to be blessed with; 
   "BindAddress", the address on the local host to bind to, defaults to 
@@ -153,18 +161,6 @@ Takes a number of optional values:
 
 Report any bugs through L<http://rt.cpan.org/>.
 
-=head1 AUTHOR
-
-Chris 'BinGOs' Williams, <chris@bingosnet.co.uk>
-
-The character generation code by Rocco Caputo.
-
-=head1 LICENSE
-
-Copyright E<copy> Chris Williams and Rocco Caputo.
-
-This module may be used, modified, and distributed under the same terms as Perl itself. Please see the license that came with your Perl distribution for details.
-
 =head1 SEE ALSO
 
 L<POE>
@@ -177,4 +173,15 @@ L<POE::Component::Server::Echo>
 
 L<http://www.faqs.org/rfcs/rfc862.html>
 
+=head1 AUTHOR
+
+Chris Williams <chris@bingosnet.co.uk>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2017 by Chris Williams.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
